;******************************************************************************
;
;    This program is free software; you can redistribute it and/or modify
;    it under the terms of the GNU General Public License as published by
;    the Free Software Foundation; either version 2 of the License, or
;    (at your option) any later version.
;
;    This program is distributed in the hope that it will be useful,
;    but WITHOUT ANY WARRANTY; without even the implied warranty of
;    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;    GNU General Public License for more details.
;
;    You should have received a copy of the GNU General Public License
;    along with this program; if not, write to the Free Software
;    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
;
;    I (Simon Wood) can be contacted via email - unilink@mungewell.org
;    or via post - 14 Kirklands Close, Baildon, West Yorkshire, England.
;
;******************************************************************************
;	Additional Info - Release version  1.8T_04
;		Modified Version : GNUnilink for MDX-5V101R
;			"Released under the GPL license, 
;					(c) H "Turboh" Ishimoto, 2004,2005"
;					   Email: ishimoto@bea.hi-ho.ne.jp
;******************************************************************************

; Main code loop - detects a 'break' and then waits for a 'packet'. Once 
; received this is interpreted and if one of the commands that we act on, the 
; PIC responds with a suitable reply.

;; Invokes ISB_P2 only in case of Display = 3.
;; "Int1secON" is a flag set by 1sec TMR0 interrupt.
;;   Remarks: See "Respond_Hello" in case of Display=1,2,3,4,5,6,7...
ReceiveBreak:
	movf	Display, 0
	xorlw	0x03
	btfss	STATUS, Z		;; check if Display=3. 
	goto	ReceiveBreak2		;; Abort Display is not equal to 3

	btfsc	Int1secON, 0		;; Int1secON = ON(1)?
	call	IssueSlaveBreak 	;; then call ISB

ReceiveBreak2:				; add by turboh Jan. 03 2004
	clrwdt				; clear WDT
	movlw	15			; 1.5ms    ;; Jan. 18 2004
	movwf	Count

ReceiveLoop1:
	movlw	delay100us			; Value for 100us 
	movwf	Count2

ReceiveLoop2:
	btfsc	OUT_PORT, ClockBit	; Test for Clock being low
	goto	ReceiveBreak2		;; (T)

	btfss	OUT_PORT, BusOnBit	; Test for BusOn being high
					;; I think it's better not to init....
	goto	ReceiveSleep		;; May 30 2004 (by Taniguchi)

	decfsz	Count2, 1		;; Reduce Count2
	goto	ReceiveLoop2		;; (T)

	decfsz	Count, 1		; Reduce Count 
	goto	ReceiveLoop1

IdleCheck:
	movlw	255			;255times (23.8us*255=6.1ms)
	movwf	Count
IdCLoop1:
	movlw	17			;17times (7*17=119instractions(=23.8us))
	movwf	Count2
IdCLoop2:
	btfsc	OUT_PORT, ClockBit	;;
	goto	ReceiveCommand		;;case Clock=High, Exit.
					;;case Clock=Low, Cont.
	btfss	OUT_PORT, DataBit	;;

	goto	IdleCheck		;; case Date=Low, Restart Loop.

	decfsz	Count2, 1		;; case Data=High, Reduce Count2
	goto	IdCLoop2		;; loop

	decfsz	Count, 1		;; Reduce Count
	goto	IdCLoop1		;; loop
	goto	ReceiveBreak		;; If Data Low is conitunued for 6ms,
					;; goto ReceiveBreak

ReceiveCommand:
	clrf	Checksum		; Clear checksum

	call	ReadByte		; Get RAD
	movwf	Rad
	addwf	Checksum, 1

	btfsc	STATUS, Z		; Test for a Zero RAD
	goto	ReceiveBreak2		;; (T)

	call	ReadByte		; Get TAD
	movwf	Tad
	addwf	Checksum, 1

	call	ReadByte		; Get CMD1
	movwf	Cmd1
	addwf	Checksum, 1

	call	ReadByte		; Get CMD2
	movwf	Cmd2
	addwf	Checksum, 1

ReceiveParity1:
	call	ReadByte
	movwf	Parity1
	subwf	Checksum, 0		; Test checksum

	btfss	STATUS, Z
	goto	ReceiveBreak2		;; (T) 

	btfss	Cmd1, 7			; Test for 'Short' commands
	goto	ReceiveEnd

RecieveMedium:
	call	ReadByte
	movwf	Data11
	addwf	Checksum, 1

	call	ReadByte
	movwf	Data12
	addwf	Checksum, 1

	call	ReadByte
	movwf	Data13
	addwf	Checksum, 1

	call	ReadByte
	movwf	Data14
	addwf	Checksum, 1

	btfss	Cmd1, 6			; Test for 'Medium' commands
	goto	ReceiveParity2

RecieveLong:
	call	ReadByte
	movwf	Data21
	addwf	Checksum, 1

	call	ReadByte
	movwf	Data22
	addwf	Checksum, 1

	call	ReadByte
	movwf	Data23
	addwf	Checksum, 1

	call	ReadByte
	movwf	Data24
	addwf	Checksum, 1

	call	ReadByte
	movwf	Data25
	addwf	Checksum, 1

ReceiveParity2:
	call	ReadByte
	movwf	Parity2
	subwf	Checksum, 0			; Test checksum

	btfss	STATUS, Z
	goto	ReceiveBreak2			;; (T) 

ReceiveEnd:
	call	ReadByte
	movwf	EndByte

	btfss	STATUS, Z
	goto	ReceiveBreak2			;; (T)

	goto	Interpret

;;**********************************************************************
ReceiveSleep:				;aprox. 0.5sec (5 * 255 * 255)100uS/70 
	btfsc	OUT_PORT, BusOnBit	;; Test for BusOn being high
	goto	ReceiveBreak		;; I'll give you another chance...

					;; You will go sleep or resume.
	movlw	0x05			;; 5
	movwf	PCNT
ReceiveSleep1:
	movlw	0xff			;; 255
	movwf	PCNT2
ReceiveSleep2:
	movlw	0xff			;; 255
	movwf	PCNT3
ReceiveSleep3:
	nop
	btfsc	OUT_PORT, BusOnBit	;; Test for BusOn being high

	goto	Resume			;; (High) something happen?
					;; Onece BusOn have gone to low....

	decfsz	PCNT3, 1		;; (Low)  
	goto	ReceiveSleep3
	decfsz	PCNT2, 1		;
	goto	ReceiveSleep2
	decfsz	PCNT, 1			;
	goto	ReceiveSleep1

	bsf	PowDown, 0		;; (set =1) PowerDown!!
	goto	Cmd_PowerOff3		;; <parse.asm>  Go Sleep.


;******************************************************************************
;; ------ End of receive.asm.
