;******************************************************************************
;
;    This program is free software; you can redistribute it and/or modify
;    it under the terms of the GNU General Public License as published by
;    the Free Software Foundation; either version 2 of the License, or
;    (at your option) any later version.
;
;    This program is distributed in the hope that it will be useful,
;    but WITHOUT ANY WARRANTY; without even the implied warranty of
;    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;    GNU General Public License for more details.
;
;    You should have received a copy of the GNU General Public License
;    along with this program; if not, write to the Free Software
;    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
;
;    I (Simon Wood) can be contacted via email - unilink@mungewell.org
;    or via post - 14 Kirklands Close, Baildon, West Yorkshire, England.
;
;******************************************************************************
;	Additional Info - Release version  1.8T_04
;		Modified Version : GNUnilink for MDX-5V101R
;			"Released under the GPL license, 
;					(c) H "Turboh" Ishimoto, 2004, 2005"
;					   Email: ishimoto@bea.hi-ho.ne.jp
;******************************************************************************

; Initializations of all the variables, called on power up on a bus reset.
SystemSetup:
	IFDEF	DEBUG
;;--DEBUG settings -------
	movlw	0x00		;; set DiskNum = 0x00
	movwf	DiskNum

	movlw	0
	movwf	TrackNum	;; set TrackNum = 0
;;------------------------
	ELSE
;;--Release settings -----
	movlw	0x0f
	movwf	DiskNum		;; set DiscNum = 0x0f (No displaying)

	movlw	0
	movwf	TrackNum	;; set TrackNum = 0
;;------------------------
	ENDIF

;;---  default DispCtrl - user selects
	movlw	DispCtrl_Inform
	movwf	DispCtrl

;;--- clear DiscName Display ON/OFF flag
	clrf	DiscNam_DSPL		


;;--- Initialize Magazine Slot Information ----------------------------
	clrf	SlotOfMag		;; for Working

	call	GetMag_Cd_EPROM		;; result -> W
	xorlw	0x09			
	movlw	0x05			;; case not 9, set 5 (6 disc changer)
	btfsc	STATUS, Z
	movlw	0x09			;; case 9, set 9 (10 disc changer)
	movwf	SlotOfMg_Cd

	call	GetMag_Md_EPROM		;; result -> W
	xorlw	0x09			
	movlw	0x05			;; case not 9, set 5 (6 disc changer)
	btfsc	STATUS, Z
	movlw	0x09			;; case 9, set 9 (10 disc changer)
	movwf	SlotOfMg_Md

	movlw	0x31			;; - controled changer's ID -
	movwf	CurSource		;; default Current Source is CD_1
;;------------------------------------------------------------------------
;;-- Initialize EEPROM CD/MD Group Config Setting (0x12) -Jun 12 2004 ----
	movlw	0xff		;; EEPROM deta for default setting (0xff)
	movwf	ee_data		;; W -> EE_Data
	movlw	MyGroupEEADR	;; EEPROM(0x2112) data for GetMyGroup -> W
	call	Eeprom_Write	;; EEPROM write
;;------------------------------------------------------------------------

;;---  MDX-5V101R can display 10 chars on the first page of display
;;      set "<AUX-IN>  "  by default.

	movlw	DiscNamADDR0		;; EEPROM:0x2120
	movwf	DiscNamADDR

	movlw	TrackNamADDR0		;; EEPROM:0x2140
	movwf	TrackNamADDR

	clrf	DSPL_ToggleC		;; set DSPL_ToggleC(0)=0 (even)

;;--- reset DisplayMode.  		Sep. 4 2004 (T)
	movlw	Show_Time		;; set "Display shows tracktime"
	movwf	DisplayMode		;;  (as default)

	bsf	PonReset_f, 0		;; set PonReset_f=1

;******************************************************************************
WarmBoot:
	call	ResetBusOnOut	;;  set BusOnOut= OFF
	clrf	MyId 		; Not cleared when PIC-Wakeup (Resume)
	clrf	MyBit		; Not cleared when PIC-Wakeup (Resume)
	clrf	MyIdCont_Flag	;; MyId Appointing flag

	movlw	MyGroupEEADR	;; EEPROM(0x2112) data for GetMyGroup -> W
	call	Eeprom_Read	;; EEPROM read -> W
	xorlw	0x01		;; check value = 1 or not
	movlw	0xff		;; case NOT 0x01, set 0xff (next = MD mode)
	btfsc	STATUS, Z	;;
	movlw	0x01		;; case 0x01,  set 0x01 (next = CD mode)
	movwf	GetMyG_Count	;; set  GetMyG_Count

	movlw	0x80
	movwf	IdleState	;; Idle
	movlw	0xC0
	movwf	MD11State	;; Ejecting
	clrf	Ej_announceF	;; Not Announced yet

;;--- Load latest DisplayMode from EEPROM	;; Sep. 23 2004 (T)
	btfsc	PonReset_f, 0	;; check PonReset_f=1
	goto	Skip_ldDsplMode	;; if set, then skip.

	movlw	DsplMode_EEADR	;; EEPROM ADDR for Display Mode
	call	Eeprom_Read	;; Result -> W
	movwf	DisplayMode	;; load DisplayMode

	movlw	DsplTglC_EEADR	;; EEPROM ADDR for Toggle on Disc Name
	call	Eeprom_Read	;; Result -> W
	movwf	DSPL_ToggleC	;; load DSPL_ToggleC

	movlw	DiscNamADDR0	;; EEPROM:0x2120
	btfsc	DSPL_ToggleC, 0	;; check 0bit position
	movlw	DiscNamADDR1	;; EEPROM:0x2130
	movwf	DiscNamADDR	;; case =0, set ADDR0, case =1, set ADDR1

Skip_ldDsplMode:
	clrf	PonReset_f	;; clear PonReset_f
	clrf	CnfChk_Count	;; reset CnfChk_Count
	
	IFDEF	DEBUG
;;--DEBUG setting --------
;;	incf	DiskNum,  1	;; countup by every re-initialize.
;;------------------------
	ENDIF

;******************************************************************************
Resume:				; PIC-Wakeup Entry
	clrf	Sleeping	;; set dongle as waken-up.
	clrf	Display
	clrf	Time1
	clrf	Time0
	clrf	Timep
	clrf	Time0i
	clrf	Time1i
	clrf	ResPeriod
	clrf	DropCheckCount
	clrf	TrackNum
	clrf	TrackNum_Dsp
	clrf	NeedToTalk
	clrf	DDir_Flag
	clrf	DDir_Num
	clrf	DSPL_Run
	clrf	Dsp_Field
	clrf	Appoint_Now

	bsf	PowDown, 0	;; set 1= "PowerDown"

	IFDEF	NextNext
;;---------------------------
	clrf	NewDiscNumP
	clrf	NewDiscNumR
;;---------------------------
	ENDIF

	clrf	Ej_announceF		;; Not Announced yet

;;--- Port Configration ----
;;--PIC16---
	IFDEF	PIC_16
	bcf	STATUS, RP0
	nop
	IFDEF	PIC_16F62x
	bcf	STATUS, RP1
	ENDIF
	clrf	OUT_PORT
	IFDEF	PIC_16F62x
	movlw	0x07			; Disable the Comparators
	movwf	CM_CONTL
	ENDIF
	bsf	STATUS, RP0		; Configure Ports
	nop
	movlw	0xE7			;;
	movwf	OUT_ENA			; Port A

	IFDEF	PIC_16
	movlw	0x01			;; (without USART)
	movwf	TRISB			; Port B
	ENDIF

	movlw	0x0F			; Set up watchdog timer
	iorwf	OPTION_REG, 1
	clrwdt

	bcf	STATUS, RP0
	clrf	OUT_PORT

	IFDEF	PIC_16
	clrf	PORTB
	ENDIF

	ENDIF	;;<PIC_16>

;;--PIC12F683---
	IFDEF	PIC_12F683
	bcf	STATUS, RP0		;; (Bank0)

	movlw	0xb0			; Disable software-controled WDT 
	movwf	WDTCON

	clrf	OUT_PORT		;; clear GPIO

	movlw	0x07			; Disable the Comparators
	movwf	CM_CONTL

	bsf	STATUS, RP0		;; (Bank1), Configure Ports

	clrf	ANSEL			; set Digital I/O

	movlw	0x00			; NOT pulled-up all
	movwf	WPU			;;

	movlw	0x3E			;; port 1 to 5 are set as Input
	movwf	OUT_ENA			;; GPIO

	clrf	IOC			; Interrupt-on-change disabled

	movlw	0x87		;; Pre-scaler setting (B'10000111')
	movwf	OPTION_REG

	clrf	INTCON			;; Disable global interrupt
	clrf	PIE1
	clrf	PCON

	movlw	B'00001110'	;; (External)
	iorwf	OSCCON, 1
	clrf	OSCTUNE

	clrwdt

	bcf	STATUS, RP0		;; (Bank0)

	clrf	OUT_PORT

	ENDIF	;;<PIC_12F683>
;;----

	IFNDEF	PIC_12F683
	IFDEF	CdMd_SW

	bsf	STATUS, RP0		;; (BANK1)
	bsf	OUT_ENA, CdNotMdBit	;; set as Iutput
	bcf	STATUS, RP0		;; (BANK0)

	movlw	0x30			; Set up Grouping - Either CD or MD
	btfss	OUT_PORT, CdNotMdBit	; unconnected = high = CD
				;; Pull-Up is highly recommended
				;; unconnected causes unstable behavior
	movlw	0xD0
	movwf	MyGroup

	ENDIF	;;<CdMd_SW>
	ENDIF	;;<NDEF PIC_12F683>

;;--- TMR1 interrupt setting    	May 22 2004  (T) 
Int1sec_Config:
;;--------------------------------------------------------------
;;  T1CKPS1=1,T1CKPS0=1,T1OSCEN=0,T1SYNC=DC=0,TMR1CS=0,TMR1ON=0
;;       ===>  T1CON=B'00110000 = 0x30
;;--------------------------------------------------------------
	movlw	0x30
	movwf	T1CON			;; 

	bsf	STATUS, RP0		;; go to Bank1
	movlw	0xd7			;; Pre-scaler setting 
	movwf	OPTION_REG

	bcf	STATUS, RP0		;; back to Bank0

	clrf	INTCON			;; Disable global interrupt
	clrf	Int1secON		;; clear Int1secON flag
	clrf	TMR1H			;; 
	clrf	TMR1L			;; 

;;--- Set BusOn_Out			;; 
					;; Once set always ON. (Jan. 25. 2005)
	call	SetBusOnOut		;; set BusOnOut=ON  

;;--- Turn the LED light ON
	call	LED_ON			;;

;;--- Relay OFF (disconnect)
	call	RelSet_OFF		;;

;;--- Goto Main Loop
	goto	ReceiveBreak

;;***********************************************************************
;; --------End of setup.asm





